@@ -11,7 +11,7 @@ from yacs.config import CfgNode
 from fandak.utils.torch import GeneralDataClass
 
 
-@dataclass
+@dataclass(repr=False)
 class GeneralBatch(GeneralDataClass):
     @classmethod
     def default_collate(cls, items: List["GeneralBatch"]) -> "GeneralBatch":
@@ -21,9 +21,8 @@ class GeneralBatch(GeneralDataClass):
         """
         values = {}
         for attr_name in items[0].get_attribute_names():
-            if isinstance(getattr(items[0], attr_name), Tensor):
-                attrs = [getattr(i, attr_name) for i in items]
-                values[attr_name] = default_collate(attrs)
+            attrs = [getattr(i, attr_name) for i in items]
+            values[attr_name] = default_collate(attrs)
 
         # noinspection PyArgumentList
         return cls(**values)
